# PyLiteral (.pyl)
A truly Pythonic config format - Designed for both humans and machines.

## Setup
```
uv venv --python 3.8
source .venv/bin/activate
```

## Running Tests
```
pytest
```

## Build and publish
```
uv build
uv publish
```
